
# Mikel_Prueba

Este código es para practicar a subir archivos a Pypi.org para nuestra clase de programación.
Está en una versión muy temprana como para meter mucho condicional.

# Comandos
- minusculas
    - Coge la frase y devuelve la frase en minúsculas (que innovador)
- mayusculas
    - Coge la frase y devuelve la frase en mayúsculas (guau, que increible)
- minusculas_en_frase
    - Coge la frase y devuelve una lista con las letras minúsculas únicas que haya en la frase 
- mayusculas_en_frase
    - Coge la frase y devuelve una lista con las letras mayúsculas únicas que haya en la frase 
- sumar
    - Coge una lista de números y suma los valores (guau)
- media
    - Coge una lista de números y calcula la media (por dios, que complejo)
- zeros
    - Coge una lista de números y cuenta cuántos ceros hay (yeahh)
- tipo
    - Coge la variable y dice su clase de variable (magistral, de alto nivel)
- varianza
    - Coge una lista de valores numéricos y calcula la varianza
- desviacion_estandar
    - Coge una lista de valores numéricos y calcula la desviación estandar.
## Authors

- Mikel Puerta


